from simpleicons.icon import Icon
merck_icon= Icon(
    title="Merck",
    slug="merck",
    hex="007A73",
    source="https://www.merck.com/",
    svg="""<svg role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><title>Merck</title><path d="M6 6a6 6 0 0112 0zm0 12a6 6 0 016-6 6 6 0 01-6-6 6 6 0 000 12 a6 6 0 1012 0zm6-6a6 6 0 016 6 6 6 0 100-12c0 3.314-2.686 6-6 6"/></svg>""",
    guidelines=None,
    license=None,
)
