from simpleicons.icon import Icon
funimation_icon= Icon(
    title="Funimation",
    slug="funimation",
    hex="5B0BB5",
    source="https://www.funimation.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Funimation</title><path d="M12 0a12 12 0 1 0 12 12A12.001 12.001 0 0 0 12 0ZM7.428 16.06h9.188s-.449 3.278-4.601 3.278c-4.15 0-4.587-3.278-4.587-3.278z"/></svg>""",
    guidelines='https://brandpad.io/funimationstyleguide',
    license=None,
)
