from simpleicons.icon import Icon
kotlin_icon= Icon(
    title="Kotlin",
    slug="kotlin",
    hex="7F52FF",
    source="https://www.jetbrains.com/company/brand/logos/",
    svg="""<svg role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><title>Kotlin</title><path d="M24 24H0V0h24L12 12Z"/></svg>""",
    guidelines='https://www.jetbrains.com/company/brand/',
    license=None,
)
